A namespace for clj-xchart with optimizations for large datasets.
A namespace for clj-xchart with optimizations for large datasets.
(extract-array-field field array)Returns a lazy List view over a Java array, including primitive arrays.
Returns a lazy List view over a Java array, including primitive arrays.
(extract-array-series keymap array)Builds a series map from an array of records without copying the array or its fields before XChart consumes them.
Builds a series map from an array of records without copying the array or its fields before XChart consumes them.
(extract-field field list)Returns an immutable view of a sequence mapped by field. Field can be a function, but is usually a keyword. The immutable view uses no additional memory. It calls field more than once for the same key.
Here, immutable means that it cannot be updated, even persistently.
Returns an immutable view of a sequence mapped by field. Field can be a function, but is usually a keyword. The immutable view uses no additional memory. It calls field more than once for the same key. Here, immutable means that it cannot be updated, even persistently.
(extract-reducible-series keymap reducible)Builds lazy field sequences from any reducible collection. This adapter
deliberately returns reducible lazy sequences and does not materialize the
source collection; use extract-series when XChart requires indexed Lists.
Builds lazy field sequences from any reducible collection. This adapter deliberately returns reducible lazy sequences and does not materialize the source collection; use `extract-series` when XChart requires indexed Lists.
(extract-series keymap coll)Transforms coll into a series map. It uses the values in keymap with extract-field. You do not need to provide :x, :y, or any key.
Example: (extract-series {:x f, :y g, :bubble bubble} coll) == {:x (extract-field f coll), :y (extract-field g coll), :bubble (extract-field bubble coll)}
Transforms coll into a series map. It uses the values in keymap with
extract-field. You do not need to provide :x, :y, or any key.
Example: (extract-series {:x f, :y g, :bubble bubble} coll)
== {:x (extract-field f coll),
:y (extract-field g coll),
:bubble (extract-field bubble coll)}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |