com.hypirion.clj-xchart.opt

A namespace for clj-xchart with optimizations for large datasets.

A namespace for clj-xchart with optimizations for large datasets.
raw docstring

extract-fieldclj

(extract-field field list)

Returns an immutable view of a sequence mapped by field. Field can be a function, but is usually a keyword. The immutable view uses no additional memory. It calls field more than once for the same key.

Here, immutable means that it cannot be updated, even persistently.

Returns an immutable view of a sequence mapped by field. Field can be a
function, but is usually a keyword. The immutable view uses no additional
memory. It calls field more than once for the same key.

Here, immutable means that it cannot be updated, even persistently.
sourceraw docstring

extract-seriesclj

(extract-series keymap coll)

Transforms coll into a series map. It uses the values in keymap with extract-field. You do not need to provide :x, :y, or any key.

Example: (extract-series {:x f, :y g, :bubble bubble} coll) == {:x (extract-field f coll), :y (extract-field g coll), :bubble (extract-field bubble coll)}

Transforms coll into a series map. It uses the values in keymap with
extract-field. You do not need to provide :x, :y, or any key.

Example: (extract-series {:x f, :y g, :bubble bubble} coll)
      == {:x (extract-field f coll),
          :y (extract-field g coll),
          :bubble (extract-field bubble coll)}
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries