A namespace for clj-xchart with several optimisations when you run on big datasets.
A namespace for clj-xchart with several optimisations when you run on big datasets.
(extract-field field list)Returns an immutable view over sequence mapped by field (can be a function, but is usually a keyword). The immutable view consumes no memory, at the expense of calling field multiple times for the same key.
Immutable in this context means cannot be updated, even persistently.
Returns an immutable view over sequence mapped by field (can be a function, but is usually a keyword). The immutable view consumes no memory, at the expense of calling field multiple times for the same key. Immutable in this context means cannot be updated, even persistently.
(extract-series keymap coll)Transforms coll into a series map by using the values in the provided keymap with exctract-field. There's no requirement to provide :x or :y (or any key at all, for that matter), although that's common.
Example: (extract-series {:x f, :y g, :bubble bubble} coll) == {:x (extract-field f coll), :y (extract-field g coll), :bubble (extract-field bubble coll)}
Transforms coll into a series map by using the values in the
provided keymap with exctract-field. There's no requirement to
provide :x or :y (or any key at all, for that matter), although
that's common.
Example: (extract-series {:x f, :y g, :bubble bubble} coll)
== {:x (extract-field f coll),
:y (extract-field g coll),
:bubble (extract-field bubble coll)}cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |